(function() {
	// Load plugin specific language pack
	tinymce.PluginManager.requireLangPack("rbktmce");

	tinymce.create("tinymce.plugins.rbktmce", {
		/**
		 * Initializes the plugin, this will be executed after the plugin has been created.
		 * This call is done before the editor instance has finished it"s initialization so use the onInit event
		 * of the editor instance to intercept that event.
		 *
		 * @param {tinymce.Editor} ed Editor instance that the plugin is initialized in.
		 * @param {string} url Absolute URL to where the plugin is located.
		 */
		init : function(ed, url) {
			// Register the command so that it can be invoked by using tinyMCE.activeEditor.execCommand("mcerbktmce");
			ed.addCommand("rbktmce_onclick", function() {
				ed.windowManager.open({
					file : url + "/rbktmce-form.php",
					width : 360 + ed.getLang("rbktmce.delta_width", 0),
					height : 220 + ed.getLang("rbktmce.delta_height", 0),
					inline : true,
					scollbars : false, // FIXME: No funciona !!!
					resizable : false  // FIXME: No funciona !!!
				}, {
					plugin_url : url,
					scollbars : false,  // FIXME: No funciona !!!
					resizable : false  // FIXME: No funciona !!!
				}); 
			});

			// Register rbktmce button
			ed.addButton("rbktmce_button", {
				title : "rbktmce.desc",
				cmd   : "rbktmce_onclick",
				image : url + "/img/button.png"
			});

			// Add a node change handler, selects the button in the UI when a image is selected
			ed.onNodeChange.add(function(ed, cm, n) {
				cm.setActive("rbktmce", n.nodeName == "IMG");
			});
		},
		
		/**
		 * Creates control instances based in the incomming name. This method is normally not
		 * needed since the addButton method of the tinymce.Editor class is a more easy way of adding buttons
		 * but you sometimes need to create more complex controls like listboxes, split buttons etc then this
		 * method can be used to create those.
		 *
		 * @param {String} n Name of the control to create.
		 * @param {tinymce.ControlManager} cm Control manager to use inorder to create new control.
		 * @return {tinymce.ui.Control} New control instance or null if no control was created.
		 */
		createControl : function(n, cm) {
			return null;
		},

		/**
		 * Returns information about the plugin as a name/value array.
		 * The current keys are longname, author, authorurl, infourl and version.
		 *
		 * @return {Object} Name/value array containing information about the plugin.
		 */
		getInfo : function() {
			return {
				longname  : "Restaurant Booking TMCE Plugin",
				author    : "moz667@listae.com",
				authorurl : "http://listae.com/",
				infourl   : "http://listae.com/restaurant-bookings-wordpress-plugin/",
				version   : "1.0"
			};
		}
	});

	// Register plugin
	tinymce.PluginManager.add("rbktmce", tinymce.plugins.rbktmce);
})();

function rbktmce_insert(form) {
	var skin = form.skin.value;
	var business_id = form.business_id.value;
	
	tinyMCE.execCommand('mceInsertContent',false, "<div class=\"rbkform rbkform-" + skin + "\">[rbkform id=\"" + business_id + "\" skin=\"" + skin + "\" /]</div>\n\n");
}

function rbktmce_cancel() {
	
}
